@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.559-4-g8d6cbab1
+package JSON::Schema::Modern; # git description: v0.560-4-g70748147
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema validator data validation structure specification
 
-our $VERSION = '0.560';
+our $VERSION = '0.561';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -366,6 +366,11 @@ sub evaluate ($self, $data, $schema_reference, $config_override = {}) {
       require JSON::Schema::Modern::Vocabulary::FormatAssertion;
     }
 
+    # we're going to set collect_annotations during evaluation when we see an unevaluated* keyword,
+    # but after we pass to a new data scope we'll clear it again.. unless we've got the config set
+    # globally for the entire evaluation, so we store that value in a high bit.
+    $state->{collect_annotations} = ($state->{collect_annotations}//0) << 8;
+
     $valid = $self->_eval_subschema($data, $schema_info->{schema}, $state);
     warn 'result is false but there are no errors' if not $valid and not $state->{errors}->@*;
   }
@@ -554,6 +559,10 @@ sub _eval_subschema ($self, $data, $schema, $state) {
   $state->{annotations} = [];
   my @new_annotations;
 
+  # in order to collect annotations from applicator keywords only when needed, we twiddle the low
+  # bit if we see a local unevaluated* keyword, and clear it again as we move on to a new data path.
+  $state->{collect_annotations} |= 0+(exists $schema->{unevaluatedItems} || exists $schema->{unevaluatedProperties});
+
   ALL_KEYWORDS:
   foreach my $vocabulary ($state->{vocabularies}->@*) {
     # [ [ $keyword => $subref|undef ], [ ... ] ]
@@ -993,7 +1002,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.560
+version 0.561
 
 =head1 SYNOPSIS
 
