@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Annotation;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains a single annotation from a JSON Schema evaluation
 
-our $VERSION = '0.560';
+our $VERSION = '0.561';
 
 use 5.020;
 use Moo;
@@ -73,7 +73,7 @@ sub TO_JSON ($self) {
 }
 
 sub dump ($self) {
-  my $encoder = JSON::MaybeXS->new(utf8 => 0, convert_blessed => 1, canonical => 1, pretty => 1);
+  my $encoder = JSON::MaybeXS->new(utf8 => 0, convert_blessed => 1, canonical => 1, indent => 1, space_after => 1);
   $encoder->indent_length(2) if $encoder->can('indent_length');
   $encoder->encode($self);
 }
@@ -94,7 +94,7 @@ JSON::Schema::Modern::Annotation - Contains a single annotation from a JSON Sche
 
 =head1 VERSION
 
-version 0.560
+version 0.561
 
 =head1 SYNOPSIS
 
